@@ -1,5 +1,5 @@
 /*
- *  $Id: group.h,v 5.23 2002-02-25 14:00:38-08 bryan Exp $
+ *  $Id: group.h,v 5.25 2002-09-20 23:04:45-07 bryan Exp $
  *
  *  Copyright conserver.com, 2000
  *
@@ -34,6 +34,12 @@
  * 4. This notice may not be removed or altered.
  */
 
+/* return values used by CheckPass()
+ */
+#define AUTH_SUCCESS	0	/* ok                                   */
+#define AUTH_NOUSER	1	/* no user                              */
+#define AUTH_INVALID	2	/* invalid password                     */
+
 typedef struct grpent {		/* group info                           */
     unsigned int id;		/* uniqueue group id                    */
     unsigned short port;	/* port group listens on                */
@@ -49,13 +55,14 @@ typedef struct grpent {		/* group info                           */
 
 #if USE_ANSI_PROTO
 extern void Spawn(GRPENT *);
-extern int CheckPass(struct passwd *, char *);
+extern int CheckPass(char *, char *);
 extern const char *strtime(time_t *);
 extern void tagLogfile(const CONSENT *, const char *, ...);
 extern void cleanupBreak(short int);
 extern void destroyGroup(GRPENT *);
 extern void destroyConsent(GRPENT *, CONSENT *);
 extern void SendClientsMsg(CONSENT *, char *);
+extern void resetMark(void);
 #else
 extern void Spawn();
 extern int CheckPass();
@@ -65,4 +72,5 @@ extern void cleanupBreak();
 extern void destroyGroup();
 extern void destroyConsent();
 extern void SendClientsMsg();
+extern void resetMark();
 #endif
